@@ -3,6 +3,6 @@ identityProviders = ['microsoft','google','facebook','linkedin','slack','twitter
 
 eventTypes = ['LocalLogin', 'LocalLogout']
 
-localVallidationValues = ['Pass', 'Fail', 'NotApplicable']
+localVallidationValues = ['pass', 'fail', 'notapplicable']
 
 forceAuthenticationTypes = ['off', 'attempt', 'force']
\ No newline at end of file
