@@ -22,7 +22,7 @@ def validateLogin(url, params, headers):
 
 
 def redirectLogin(url, params):
-    r = requests.get(url+'/redirect', params=params)
+    r = requests.get(url+'/redirect', params=params, allow_redirects=False)
     return r
 
 
